@@ -1,5 +1,4 @@
 import janda
-import json
 import requests
 import os
 import re
@@ -11,11 +10,14 @@ from .utils.misc import (
     convert_html_to_pdf,
     project,
     get_size_folder,
-    need_args,
+    log_data,
+    log_file,
+    log_final,
 )
 from inputimeout import inputimeout, TimeoutOccurred
 
 h2r = janda.Hentai2read()
+t: str = "tomoe.html"
 
 value = choose().hentai2read
 if value is None:
@@ -32,18 +34,17 @@ async def get_h2r(id: str = par1, chapter: int = par2):
     initial = time.time()
     data = await h2r.get(id[0], chapter)
     parser = janda.resolve(data)
-    title = parser["title"]
-    title = re.sub(r"[^\w\s]", "", title)
-    print(f"Title: {title}")
 
-    img = parser["images"]
-    print(f"Total image: {len(img)}")
+    title = re.sub(r"[^\w\s]", "", parser["data"]["title"])
+    img = parser["data"]["image"]
+    slug = parser["data"]["id"]
+
+    log_data("TITLE", title)
+    log_data("ID", slug)
+    log_data("SOURCE", parser["current_url"])
+    log_data("TOTAL", f"{len(parser['data']['image'])} pages")
+
     neat_dir = split_name(__file__) + " - " + title
-
-    set_name = parser["currentURL"]
-    set_name = set_name.split("/")[-3]
-    print(f"Set name: {set_name}")
-
     if not os.path.exists(neat_dir):
         os.makedirs(neat_dir)
 
@@ -59,25 +60,28 @@ async def get_h2r(id: str = par1, chapter: int = par2):
         img_url = i
         img_name = img_url.rsplit("/", 1)[-1]
 
-        r = requests.get(f"https://static.hentaicdn.com/hentai{img_url}")
+        r = requests.get(img_url)
         with open(neat_dir + "/" + img_name, "wb") as f:
+
             f.write(r.content)
 
             if os.path.exists(neat_dir + "/" + img_name):
-                print(
-                    f'Successfully downloaded {img_name} | {get_size(neat_dir + "/" + img_name)} MB | took {time.time() - start:.2f} seconds'
+                log_file(
+                    img_name,
+                    get_size(neat_dir + "/" + img_name),
+                    f"{time.time() - start:.2f}",
                 )
 
             if len(img) == len(os.listdir(neat_dir)):
 
-                print(
-                    f"Successfully downloaded all images taken {(time.time() - initial) / 60:.2f} minutes with total size {get_size_folder(neat_dir)} MB"
+                log_final(
+                    f"{(time.time() - initial) / 60:.2f}", get_size_folder(neat_dir)
                 )
                 print(f"Directory: {os.path.abspath(neat_dir)}")
 
-                with open(neat_dir + "/tomoe.html", "x", encoding="utf-8") as f:
+                with open(neat_dir + "/" + t, "x", encoding="utf-8") as f:
                     f.write("<html><center><body>")
-                    f.write(f"<h1>{set_name}</h1>")
+                    f.write(f"<h1>{parser['data']['title']}</h1>")
 
                     for i in img:
                         file = i.rsplit("/", 1)[-1]
@@ -96,8 +100,8 @@ async def get_h2r(id: str = par1, chapter: int = par2):
 
                     if to_pdf == "y":
                         try:
-                            source = open(f"{neat_dir}/tomoe.html")
-                            output = f"{neat_dir}/{set_name}.pdf"
+                            source = open(f"{neat_dir}/{t}")
+                            output = f"{neat_dir}/{parser['data']['title']}.pdf"
                             filepdf = output.rsplit("/", 1)[-1]
 
                             convert_html_to_pdf(source, output)
@@ -110,15 +114,15 @@ async def get_h2r(id: str = par1, chapter: int = par2):
 
                     elif to_pdf == "n":
                         print("Okay")
-                        os.remove(neat_dir + "/tomoe.html")
+                        os.remove(neat_dir + "/" + t)
                         return
 
                     else:
                         print("Invalid input")
-                        os.remove(neat_dir + "/tomoe.html")
+                        os.remove(neat_dir + "/" + t)
                         return
 
                 except TimeoutOccurred:
                     print("Timeout occurred")
-                    os.remove(neat_dir + "/tomoe.html")
+                    os.remove(neat_dir + "/" + t)
                     exit()
