@@ -1,5 +1,4 @@
 import janda
-import json
 import requests
 import os
 import re
@@ -11,24 +10,33 @@ from .utils.misc import (
     convert_html_to_pdf,
     project,
     get_size_folder,
+    log_data,
+    log_file,
+    log_final,
 )
 from inputimeout import inputimeout, TimeoutOccurred
 
 hfox = janda.Hentaifox()
+t: str = "tomoe.html"
 
 
 async def get_hfox(id: int = choose().hentaifox):
     initial = time.time()
     data = await hfox.get(id)
     parser = janda.resolve(data)
-    title = parser["title"]
-    title = re.sub(r"[^\w\s]", "", title)
-    number = parser["id"]
-    print(f"Title: {title}")
 
-    img = parser["images"]
-    print(f"Total image: {len(img)}")
-    print(f'Tags: {parser["tags"]}')
+    title = re.sub(r"[^\w\s]", "", parser["data"]["title"])
+    img = parser["data"]["image"]
+    number = parser["data"]["id"]
+    tags = parser["data"]["tags"]
+    tags = [tag for tag in tags]
+    to_tags = ", ".join(tags)
+
+    log_data("TITLE", title)
+    log_data("TAGS", to_tags)
+    log_data("ID", number)
+    log_data("SOURCE", parser["source"])
+    log_data("TOTAL", f"{parser['data']['total']} pages")
 
     neat_dir = f"{split_name(__file__)}-{number}-{title}"
     neat_dir = re.sub("[^A-Za-z0-9-]+", " ", neat_dir)
@@ -66,19 +74,20 @@ async def get_hfox(id: int = choose().hentaifox):
             f.write(r.content)
 
             if os.path.exists(neat_dir + "/" + img_name):
-                print(
-                    f'Successfully downloaded {img_name} | {get_size(neat_dir + "/" + img_name)} MB | took {time.time() - start:.2f} seconds'
+                log_file(
+                    img_name,
+                    get_size(neat_dir + "/" + img_name),
+                    f"{time.time() - start:.2f}",
                 )
 
             if len(img) == len(os.listdir(neat_dir)):
-
-                print(
-                    f"Successfully downloaded all images taken {(time.time() - initial) / 60:.2f} minutes with total size {get_size_folder(neat_dir)} MB"
+                log_final(
+                    f"{(time.time() - initial) / 60:.2f}", get_size_folder(neat_dir)
                 )
 
-                with open(neat_dir + "/tomoe.html", "x", encoding="utf-8") as f:
+                with open(neat_dir + "/" + t, "x", encoding="utf-8") as f:
                     f.write("<html><center><body>")
-                    f.write(f"<h1>{parser['id']}</h1>")
+                    f.write(f"<h1>{parser['data']['id']}</h1>")
 
                     for i in img:
                         img_url = i
@@ -92,7 +101,7 @@ async def get_hfox(id: int = choose().hentaifox):
                                 )
                         except:
                             img_url = img_url.replace(".jpg", ".png")
-                        ## get after last slash in img, example /1.jpg
+
                         file = img_url.rsplit("/", 1)[-1]
 
                         f.write(f'<img src="{neat_dir}/{file}"><p></p>')
@@ -111,8 +120,8 @@ async def get_hfox(id: int = choose().hentaifox):
 
                     if to_pdf == "y":
                         try:
-                            source = open(f"{neat_dir}/tomoe.html")
-                            output = f"{neat_dir}/{parser['id']}.pdf"
+                            source = open(f"{neat_dir}/{t}")
+                            output = f"{neat_dir}/{parser['data']['id']}.pdf"
                             filepdf = output.rsplit("/", 1)[-1]
 
                             convert_html_to_pdf(source, output)
@@ -125,15 +134,15 @@ async def get_hfox(id: int = choose().hentaifox):
 
                     elif to_pdf == "n":
                         print("Okay")
-                        os.remove(neat_dir + "/tomoe.html")
+                        os.remove(neat_dir + "/" + t)
                         return
 
                     else:
                         print("Invalid input")
-                        os.remove(neat_dir + "/tomoe.html")
+                        os.remove(neat_dir + "/" + t)
                         return
 
                 except TimeoutOccurred:
                     print("Timeout occurred")
-                    os.remove(neat_dir + "/tomoe.html")
+                    os.remove(neat_dir + "/" + t)
                     exit()
